@@ -52,21 +52,15 @@
  * @Title: GtkTextTag
  * @Short_description: A tag that can be applied to text in a GtkTextBuffer
  *
- * You may wish to begin by reading the
- * [text widget conceptual overview][TextWidget]
- * which gives an overview of all the objects and
+ * You may wish to begin by reading the <link linkend="TextWidget">text widget
+ * conceptual overview</link> which gives an overview of all the objects and
  * data types related to the text widget and how they work together.
  *
  * Tags should be in the #GtkTextTagTable for a given #GtkTextBuffer
  * before using them with that buffer.
  *
  * gtk_text_buffer_create_tag() is the best way to create tags.
- * See “gtk3-demo” for numerous examples.
- *
- * For each property of #GtkTextTag, there is a “set” property, e.g.
- * “font-set” corresponds to “font”. These “set” properties reflect
- * whether a property has been set or not.
- * They are maintained by GTK+ and you should not set them independently.
+ * See <application>gtk3-demo</application> for numerous examples.
  */
 
 #include "config.h"
@@ -74,7 +68,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "gtktextattributesprivate.h"
+#include "gtkmainprivate.h"
 #include "gtktexttag.h"
 #include "gtktexttypes.h"
 #include "gtktexttagtable.h"
@@ -120,10 +114,8 @@ enum {
   PROP_LEFT_MARGIN,
   PROP_INDENT,
   PROP_STRIKETHROUGH,
-  PROP_STRIKETHROUGH_RGBA,
   PROP_RIGHT_MARGIN,
   PROP_UNDERLINE,
-  PROP_UNDERLINE_RGBA,
   PROP_RISE,
   PROP_BACKGROUND_FULL_HEIGHT,
   PROP_LANGUAGE,
@@ -132,13 +124,10 @@ enum {
   PROP_PARAGRAPH_BACKGROUND,
   PROP_PARAGRAPH_BACKGROUND_GDK,
   PROP_PARAGRAPH_BACKGROUND_RGBA,
-  PROP_FALLBACK,
-  PROP_LETTER_SPACING,
-  PROP_FONT_FEATURES,
 
   /* Behavior args */
   PROP_ACCUMULATIVE_MARGIN,
-
+  
   /* Whether-a-style-arg-is-set args */
   PROP_BACKGROUND_SET,
   PROP_FOREGROUND_SET,
@@ -158,19 +147,14 @@ enum {
   PROP_LEFT_MARGIN_SET,
   PROP_INDENT_SET,
   PROP_STRIKETHROUGH_SET,
-  PROP_STRIKETHROUGH_RGBA_SET,
   PROP_RIGHT_MARGIN_SET,
   PROP_UNDERLINE_SET,
-  PROP_UNDERLINE_RGBA_SET,
   PROP_RISE_SET,
   PROP_BACKGROUND_FULL_HEIGHT_SET,
   PROP_LANGUAGE_SET,
   PROP_TABS_SET,
   PROP_INVISIBLE_SET,
   PROP_PARAGRAPH_BACKGROUND_SET,
-  PROP_FALLBACK_SET,
-  PROP_LETTER_SPACING_SET,
-  PROP_FONT_FEATURES_SET,
 
   LAST_ARG
 };
@@ -186,7 +170,7 @@ static void gtk_text_tag_get_property (GObject         *object,
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (GtkTextTag, gtk_text_tag, G_TYPE_OBJECT)
+G_DEFINE_TYPE (GtkTextTag, gtk_text_tag, G_TYPE_OBJECT)
 
 static void
 gtk_text_tag_class_init (GtkTextTagClass *klass)
@@ -217,20 +201,13 @@ gtk_text_tag_class_init (GtkTextTagClass *klass)
                                                         NULL,
                                                         GTK_PARAM_WRITABLE));
 
-  /**
-   * GtkTextTag:background-gdk:
-   *
-   * Background color as a #GdkColor.
-   *
-   * Deprecated: 3.4: Use #GtkTextTag:background-rgba instead.
-   */
   g_object_class_install_property (object_class,
                                    PROP_BACKGROUND_GDK,
                                    g_param_spec_boxed ("background-gdk",
                                                        P_("Background color"),
                                                        P_("Background color as a GdkColor"),
-                                                       g_type_from_name ("GdkColor"),
-                                                       GTK_PARAM_READWRITE | G_PARAM_DEPRECATED));
+                                                       GDK_TYPE_COLOR,
+                                                       GTK_PARAM_READWRITE));
 
   /**
    * GtkTextTag:background-rgba:
@@ -242,7 +219,7 @@ gtk_text_tag_class_init (GtkTextTagClass *klass)
   g_object_class_install_property (object_class,
                                    PROP_BACKGROUND_RGBA,
                                    g_param_spec_boxed ("background-rgba",
-                                                       P_("Background RGBA"),
+                                                       P_("Background rgba"),
                                                        P_("Background color as a GdkRGBA"),
                                                        GDK_TYPE_RGBA,
                                                        GTK_PARAM_READWRITE));
@@ -263,20 +240,13 @@ gtk_text_tag_class_init (GtkTextTagClass *klass)
                                                         NULL,
                                                         GTK_PARAM_WRITABLE));
 
-  /**
-   * GtkTextTag:foreground-gdk:
-   *
-   * Foreground color as a #GdkColor.
-   *
-   * Deprecated: 3.4: Use #GtkTextTag:foreground-rgba instead.
-   */
   g_object_class_install_property (object_class,
                                    PROP_FOREGROUND_GDK,
                                    g_param_spec_boxed ("foreground-gdk",
                                                        P_("Foreground color"),
                                                        P_("Foreground color as a GdkColor"),
-                                                       g_type_from_name ("GdkColor"),
-                                                       GTK_PARAM_READWRITE | G_PARAM_DEPRECATED));
+                                                       GDK_TYPE_COLOR,
+                                                       GTK_PARAM_READWRITE));
 
   /**
    * GtkTextTag:foreground-rgba:
@@ -288,7 +258,7 @@ gtk_text_tag_class_init (GtkTextTagClass *klass)
   g_object_class_install_property (object_class,
                                    PROP_FOREGROUND_RGBA,
                                    g_param_spec_boxed ("foreground-rgba",
-                                                       P_("Foreground RGBA"),
+                                                       P_("Foreground rgba"),
                                                        P_("Foreground color as a GdkRGBA"),
                                                        GDK_TYPE_RGBA,
                                                        GTK_PARAM_READWRITE));
@@ -525,43 +495,7 @@ gtk_text_tag_class_init (GtkTextTagClass *klass)
                                                       PANGO_TYPE_UNDERLINE,
                                                       PANGO_UNDERLINE_NONE,
                                                       GTK_PARAM_READWRITE));
-
-  /**
-   * GtkTextTag:underline-rgba:
-   *
-   * This property modifies the color of underlines. If not set, underlines
-   * will use the forground color.
-   *
-   * If #GtkTextTag:underline is set to %PANGO_UNDERLINE_ERROR, an alternate
-   * color may be applied instead of the foreground. Setting this property
-   * will always override those defaults.
-   *
-   * Since: 3.16
-   */
-  g_object_class_install_property (object_class,
-                                   PROP_UNDERLINE_RGBA,
-                                   g_param_spec_boxed ("underline-rgba",
-                                                       P_("Underline RGBA"),
-                                                       P_("Color of underline for this text"),
-                                                       GDK_TYPE_RGBA,
-                                                       GTK_PARAM_READWRITE));
-
-  /**
-   * GtkTextTag:strikethrough-rgba:
-   *
-   * This property modifies the color of strikeouts. If not set, strikeouts
-   * will use the forground color.
-   *
-   * Since: 3.16
-   */
-  g_object_class_install_property (object_class,
-                                   PROP_STRIKETHROUGH_RGBA,
-                                   g_param_spec_boxed ("strikethrough-rgba",
-                                                       P_("Strikethrough RGBA"),
-                                                       P_("Color of strikethrough for this text"),
-                                                       GDK_TYPE_RGBA,
-                                                       GTK_PARAM_READWRITE));
-
+  
   g_object_class_install_property (object_class,
                                    PROP_WRAP_MODE,
                                    g_param_spec_enum ("wrap-mode",
@@ -617,83 +551,33 @@ gtk_text_tag_class_init (GtkTextTagClass *klass)
   /**
    * GtkTextTag:paragraph-background-gdk:
    *
-   * The paragraph background color as a #GdkColor.
+   * The paragraph background color as a as a #GdkColor.
    *
    * Since: 2.8
-   *
-   * Deprecated: 3.4: Use #GtkTextTag:paragraph-background-rgba instead.
    */
   g_object_class_install_property (object_class,
                                    PROP_PARAGRAPH_BACKGROUND_GDK,
                                    g_param_spec_boxed ("paragraph-background-gdk",
                                                        P_("Paragraph background color"),
                                                        P_("Paragraph background color as a GdkColor"),
-                                                       g_type_from_name ("GdkColor"),
-                                                       GTK_PARAM_READWRITE | G_PARAM_DEPRECATED));
+                                                       GDK_TYPE_COLOR,
+                                                       GTK_PARAM_READWRITE));
 
   /**
    * GtkTextTag:paragraph-background-rgba:
    *
-   * The paragraph background color as a #GdkRGBA.
+   * The paragraph background color as a as a #GdkRGBA.
    *
    * Since: 3.2
    */
   g_object_class_install_property (object_class,
                                    PROP_PARAGRAPH_BACKGROUND_RGBA,
                                    g_param_spec_boxed ("paragraph-background-rgba",
-                                                       P_("Paragraph background RGBA"),
-                                                       P_("Paragraph background RGBA as a GdkRGBA"),
+                                                       P_("Paragraph background rgba"),
+                                                       P_("Paragraph background rgba as a GdkRGBA"),
                                                        GDK_TYPE_RGBA,
                                                        GTK_PARAM_READWRITE));
 
-  /**
-   * GtkTextTag:fallback:
-   *
-   * Whether font fallback is enabled.
-   *
-   * When set to %TRUE, other fonts will be substituted
-   * where the current font is missing glyphs.
-   *
-   * Since: 3.16
-   */
-  g_object_class_install_property (object_class,
-                                   PROP_FALLBACK,
-                                   g_param_spec_boolean ("fallback",
-                                                         P_("Fallback"),
-                                                         P_("Whether font fallback is enabled."),
-                                                         TRUE,
-                                                         GTK_PARAM_READWRITE));
-
-  /**
-   * GtkTextTag:letter-spacing:
-   *
-   * Extra spacing between graphemes, in Pango units.
-   *
-   * Since: 3.16
-   */
-  g_object_class_install_property (object_class,
-                                   PROP_LETTER_SPACING,
-                                   g_param_spec_int ("letter-spacing",
-                                                     P_("Letter Spacing"),
-                                                     P_("Extra spacing between graphemes"),
-                                                     0, G_MAXINT, 0,
-                                                     GTK_PARAM_READWRITE));
-
-  /**
-   * GtkTextTag:font-features:
-   *
-   * OpenType font features, as a string.
-   *
-   * Since: 3.18
-   */
-  g_object_class_install_property (object_class,
-                                   PROP_FONT_FEATURES,
-                                   g_param_spec_string ("font-features",
-                                                        P_("Font Features"),
-                                                        P_("OpenType Font Features to use"),
-                                                        NULL,
-                                                        GTK_PARAM_READWRITE));
-
   /**
    * GtkTextTag:accumulative-margin:
    *
@@ -805,28 +689,6 @@ gtk_text_tag_class_init (GtkTextTagClass *klass)
                 P_("Underline set"),
                 P_("Whether this tag affects underlining"));
 
-  /**
-   * GtkTextTag:underline-rgba-set:
-   *
-   * If the #GtkTextTag:underline-rgba property has been set.
-   *
-   * Since: 3.16
-   */
-  ADD_SET_PROP ("underline-rgba-set", PROP_UNDERLINE_RGBA_SET,
-                P_("Underline RGBA set"),
-                P_("Whether this tag affects underlining color"));
-
-  /**
-   * GtkTextTag:strikethrough-rgba-set:
-   *
-   * If the #GtkTextTag:strikethrough-rgba property has been set.
-   *
-   * Since: 3.16
-   */
-  ADD_SET_PROP ("strikethrough-rgba-set", PROP_STRIKETHROUGH_RGBA_SET,
-                P_("Strikethrough RGBA set"),
-                P_("Whether this tag affects strikethrough color"));
-
   ADD_SET_PROP ("wrap-mode-set", PROP_WRAP_MODE_SET,
                 P_("Wrap mode set"),
                 P_("Whether this tag affects line wrap mode"));
@@ -843,18 +705,6 @@ gtk_text_tag_class_init (GtkTextTagClass *klass)
                 P_("Paragraph background set"),
                 P_("Whether this tag affects the paragraph background color"));
 
-  ADD_SET_PROP ("fallback-set", PROP_FALLBACK_SET,
-                P_("Fallback set"),
-                P_("Whether this tag affects font fallback"));
-
-  ADD_SET_PROP ("letter-spacing-set", PROP_LETTER_SPACING_SET,
-                P_("Letter spacing set"),
-                P_("Whether this tag affects letter spacing"));
-
-  ADD_SET_PROP ("font-features-set", PROP_FONT_FEATURES_SET,
-                P_("Font features set"),
-                P_("Whether this tag affects font features"));
-
   /**
    * GtkTextTag::event:
    * @tag: the #GtkTextTag on which the signal is emitted
@@ -880,13 +730,21 @@ gtk_text_tag_class_init (GtkTextTagClass *klass)
                   G_TYPE_OBJECT,
                   GDK_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE,
                   GTK_TYPE_TEXT_ITER);
+
+  g_type_class_add_private (klass, sizeof (GtkTextTagPrivate));
 }
 
 static void
 gtk_text_tag_init (GtkTextTag *text_tag)
 {
-  text_tag->priv = gtk_text_tag_get_instance_private (text_tag);
-  text_tag->priv->values = gtk_text_attributes_new ();
+  GtkTextTagPrivate *priv;
+
+  text_tag->priv = G_TYPE_INSTANCE_GET_PRIVATE (text_tag,
+                                                GTK_TYPE_TEXT_TAG,
+                                                GtkTextTagPrivate);
+  priv = text_tag->priv;
+
+  priv->values = gtk_text_attributes_new ();
 }
 
 /**
@@ -896,7 +754,7 @@ gtk_text_tag_init (GtkTextTag *text_tag)
  * Creates a #GtkTextTag. Configure the tag using object arguments,
  * i.e. using g_object_set().
  * 
- * Returns: a new #GtkTextTag
+ * Return value: a new #GtkTextTag
  **/
 GtkTextTag*
 gtk_text_tag_new (const gchar *name)
@@ -947,66 +805,6 @@ copy_gdk_color_to_rgba (GdkColor *src,
   dest->alpha = 1;
 }
 
-static void
-set_underline_rgba (GtkTextTag    *tag,
-                    const GdkRGBA *rgba)
-{
-  GtkTextTagPrivate *priv = tag->priv;
-
-  if (rgba)
-    {
-      GTK_TEXT_APPEARANCE_SET_UNDERLINE_RGBA (&priv->values->appearance, rgba);
-
-      if (!GTK_TEXT_APPEARANCE_GET_UNDERLINE_RGBA_SET (&priv->values->appearance))
-        {
-          GTK_TEXT_APPEARANCE_SET_UNDERLINE_RGBA_SET (&priv->values->appearance, TRUE);
-          g_object_notify (G_OBJECT (tag), "underline-rgba-set");
-        }
-    }
-  else
-    {
-      GdkRGBA black = { 0 };
-
-      GTK_TEXT_APPEARANCE_SET_UNDERLINE_RGBA (&priv->values->appearance, &black);
-
-      if (GTK_TEXT_APPEARANCE_GET_UNDERLINE_RGBA_SET (&priv->values->appearance))
-        {
-          GTK_TEXT_APPEARANCE_SET_UNDERLINE_RGBA_SET (&priv->values->appearance, FALSE);
-          g_object_notify (G_OBJECT (tag), "underline-rgba-set");
-        }
-    }
-}
-
-static void
-set_strikethrough_rgba (GtkTextTag    *tag,
-                        const GdkRGBA *rgba)
-{
-  GtkTextTagPrivate *priv = tag->priv;
-
-  if (rgba)
-    {
-      GTK_TEXT_APPEARANCE_SET_STRIKETHROUGH_RGBA (&priv->values->appearance, rgba);
-
-      if (!GTK_TEXT_APPEARANCE_GET_STRIKETHROUGH_RGBA_SET (&priv->values->appearance))
-        {
-          GTK_TEXT_APPEARANCE_SET_STRIKETHROUGH_RGBA_SET (&priv->values->appearance, TRUE);
-          g_object_notify (G_OBJECT (tag), "strikethrough-rgba-set");
-        }
-    }
-  else
-    {
-      GdkRGBA black = { 0 };
-
-      GTK_TEXT_APPEARANCE_SET_STRIKETHROUGH_RGBA (&priv->values->appearance, &black);
-
-      if (GTK_TEXT_APPEARANCE_GET_STRIKETHROUGH_RGBA_SET (&priv->values->appearance))
-        {
-          GTK_TEXT_APPEARANCE_SET_STRIKETHROUGH_RGBA_SET (&priv->values->appearance, FALSE);
-          g_object_notify (G_OBJECT (tag), "strikethrough-rgba-set");
-        }
-    }
-}
-
 static void
 set_bg_rgba (GtkTextTag *tag, GdkRGBA *rgba)
 {
@@ -1079,10 +877,8 @@ set_pg_bg_rgba (GtkTextTag *tag, GdkRGBA *rgba)
   if (priv->values->pg_bg_rgba)
     gdk_rgba_free (priv->values->pg_bg_rgba);
 
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   if (priv->values->pg_bg_color)
     gdk_color_free (priv->values->pg_bg_color);
-G_GNUC_END_IGNORE_DEPRECATIONS
 
   priv->values->pg_bg_rgba = NULL;
   priv->values->pg_bg_color = NULL;
@@ -1100,9 +896,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
       priv->values->pg_bg_rgba = gdk_rgba_copy (rgba);
 
       copy_rgba_to_gdk_color (rgba, &color);
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
       priv->values->pg_bg_color = gdk_color_copy (&color);
-G_GNUC_END_IGNORE_DEPRECATIONS
     }
   else
     {
@@ -1344,7 +1138,7 @@ gtk_text_tag_set_property (GObject      *object,
         else if (gdk_rgba_parse (&rgba, g_value_get_string (value)))
           set_bg_rgba (text_tag, &rgba);
         else
-          g_warning ("Don't know color '%s'", g_value_get_string (value));
+          g_warning ("Don't know color `%s'", g_value_get_string (value));
 
         g_object_notify (object, "background-gdk");
       }
@@ -1359,7 +1153,7 @@ gtk_text_tag_set_property (GObject      *object,
         else if (gdk_rgba_parse (&rgba, g_value_get_string (value)))
           set_fg_rgba (text_tag, &rgba);
         else
-          g_warning ("Don't know color '%s'", g_value_get_string (value));
+          g_warning ("Don't know color `%s'", g_value_get_string (value));
 
         g_object_notify (object, "foreground-gdk");
       }
@@ -1554,13 +1348,6 @@ gtk_text_tag_set_property (GObject      *object,
       g_object_notify (object, "strikethrough-set");
       break;
 
-    case PROP_STRIKETHROUGH_RGBA:
-      {
-        GdkRGBA *color = g_value_get_boxed (value);
-        set_strikethrough_rgba (text_tag, color);
-      }
-      break;
-
     case PROP_RIGHT_MARGIN:
       priv->right_margin_set = TRUE;
       priv->values->right_margin = g_value_get_int (value);
@@ -1574,13 +1361,6 @@ gtk_text_tag_set_property (GObject      *object,
       g_object_notify (object, "underline-set");
       break;
 
-    case PROP_UNDERLINE_RGBA:
-      {
-        GdkRGBA *color = g_value_get_boxed (value);
-        set_underline_rgba (text_tag, color);
-      }
-      break;
-
     case PROP_RISE:
       priv->rise_set = TRUE;
       priv->values->appearance.rise = g_value_get_int (value);
@@ -1631,7 +1411,7 @@ gtk_text_tag_set_property (GObject      *object,
         else if (gdk_rgba_parse (&rgba, g_value_get_string (value)))
           set_pg_bg_rgba (text_tag, &rgba);
         else
-          g_warning ("Don't know color '%s'", g_value_get_string (value));
+          g_warning ("Don't know color `%s'", g_value_get_string (value));
 
         g_object_notify (object, "paragraph-background-gdk");
       }
@@ -1653,24 +1433,6 @@ gtk_text_tag_set_property (GObject      *object,
       }
       break;
 
-    case PROP_FALLBACK:
-      priv->fallback_set = TRUE;
-      priv->values->no_fallback = !g_value_get_boolean (value);
-      g_object_notify (object, "fallback-set");
-      break;
-
-    case PROP_LETTER_SPACING:
-      priv->letter_spacing_set = TRUE;
-      priv->values->letter_spacing = g_value_get_int (value);
-      g_object_notify (object, "letter-spacing-set");
-      break;
-
-    case PROP_FONT_FEATURES:
-      priv->font_features_set = TRUE;
-      priv->values->font_features = g_value_dup_string (value);
-      g_object_notify (object, "font-features-set");
-      break;
-
     case PROP_ACCUMULATIVE_MARGIN:
       priv->accumulative_margin = g_value_get_boolean (value);
       g_object_notify (object, "accumulative-margin");
@@ -1758,11 +1520,6 @@ gtk_text_tag_set_property (GObject      *object,
       priv->strikethrough_set = g_value_get_boolean (value);
       break;
 
-    case PROP_STRIKETHROUGH_RGBA_SET:
-      GTK_TEXT_APPEARANCE_SET_STRIKETHROUGH_RGBA_SET (&priv->values->appearance,
-                                                      g_value_get_boolean (value));
-      break;
-
     case PROP_RIGHT_MARGIN_SET:
       priv->right_margin_set = g_value_get_boolean (value);
       size_changed = TRUE;
@@ -1772,11 +1529,6 @@ gtk_text_tag_set_property (GObject      *object,
       priv->underline_set = g_value_get_boolean (value);
       break;
 
-    case PROP_UNDERLINE_RGBA_SET:
-      GTK_TEXT_APPEARANCE_SET_UNDERLINE_RGBA_SET (&priv->values->appearance,
-                                                  g_value_get_boolean (value));
-      break;
-
     case PROP_RISE_SET:
       priv->rise_set = g_value_get_boolean (value);
       size_changed = TRUE;
@@ -1805,18 +1557,6 @@ gtk_text_tag_set_property (GObject      *object,
       priv->pg_bg_color_set = g_value_get_boolean (value);
       break;
 
-    case PROP_FALLBACK_SET:
-      priv->fallback_set = g_value_get_boolean (value);
-      break;
-
-    case PROP_LETTER_SPACING_SET:
-      priv->letter_spacing_set = g_value_get_boolean (value);
-      break;
-
-    case PROP_FONT_FEATURES_SET:
-      priv->font_features_set = g_value_get_boolean (value);
-      break;
-
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -1969,16 +1709,6 @@ gtk_text_tag_get_property (GObject      *object,
       g_value_set_boolean (value, priv->values->appearance.strikethrough);
       break;
 
-    case PROP_STRIKETHROUGH_RGBA:
-      if (GTK_TEXT_APPEARANCE_GET_STRIKETHROUGH_RGBA_SET (&priv->values->appearance))
-        {
-          GdkRGBA rgba;
-
-          GTK_TEXT_APPEARANCE_GET_STRIKETHROUGH_RGBA (&priv->values->appearance, &rgba);
-          g_value_set_boxed (value, &rgba);
-        }
-      break;
-
     case PROP_RIGHT_MARGIN:
       g_value_set_int (value, priv->values->right_margin);
       break;
@@ -1987,16 +1717,6 @@ gtk_text_tag_get_property (GObject      *object,
       g_value_set_enum (value, priv->values->appearance.underline);
       break;
 
-    case PROP_UNDERLINE_RGBA:
-      if (GTK_TEXT_APPEARANCE_GET_UNDERLINE_RGBA_SET (&priv->values->appearance))
-        {
-          GdkRGBA rgba;
-
-          GTK_TEXT_APPEARANCE_GET_UNDERLINE_RGBA (&priv->values->appearance, &rgba);
-          g_value_set_boxed (value, &rgba);
-        }
-      break;
-
     case PROP_RISE:
       g_value_set_int (value, priv->values->appearance.rise);
       break;
@@ -2026,18 +1746,6 @@ gtk_text_tag_get_property (GObject      *object,
       g_value_set_boxed (value, priv->values->pg_bg_rgba);
       break;
 
-    case PROP_FALLBACK:
-      g_value_set_boolean (value, !priv->values->no_fallback);
-      break;
-
-    case PROP_LETTER_SPACING:
-      g_value_set_int (value, priv->values->letter_spacing);
-      break;
-
-    case PROP_FONT_FEATURES:
-      g_value_set_string (value, priv->values->font_features);
-      break;
-
     case PROP_ACCUMULATIVE_MARGIN:
       g_value_set_boolean (value, priv->accumulative_margin);
       break;
@@ -2104,11 +1812,6 @@ gtk_text_tag_get_property (GObject      *object,
       g_value_set_boolean (value, priv->strikethrough_set);
       break;
 
-    case PROP_STRIKETHROUGH_RGBA_SET:
-      g_value_set_boolean (value,
-                           GTK_TEXT_APPEARANCE_GET_STRIKETHROUGH_RGBA_SET (&priv->values->appearance));
-      break;
-
     case PROP_RIGHT_MARGIN_SET:
       g_value_set_boolean (value, priv->right_margin_set);
       break;
@@ -2117,11 +1820,6 @@ gtk_text_tag_get_property (GObject      *object,
       g_value_set_boolean (value, priv->underline_set);
       break;
 
-    case PROP_UNDERLINE_RGBA_SET:
-      g_value_set_boolean (value,
-                           GTK_TEXT_APPEARANCE_GET_UNDERLINE_RGBA_SET (&priv->values->appearance));
-      break;
-
     case PROP_RISE_SET:
       g_value_set_boolean (value, priv->rise_set);
       break;
@@ -2146,18 +1844,6 @@ gtk_text_tag_get_property (GObject      *object,
       g_value_set_boolean (value, priv->pg_bg_color_set);
       break;
 
-    case PROP_FALLBACK_SET:
-      g_value_set_boolean (value, priv->fallback_set);
-      break;
-
-    case PROP_LETTER_SPACING_SET:
-      g_value_set_boolean (value, priv->letter_spacing_set);
-      break;
-
-    case PROP_FONT_FEATURES_SET:
-      g_value_set_boolean (value, priv->font_features_set);
-      break;
-
     case PROP_BACKGROUND:
     case PROP_FOREGROUND:
     case PROP_PARAGRAPH_BACKGROUND:
@@ -2195,7 +1881,7 @@ delta_priority_foreach (GtkTextTag *tag, gpointer user_data)
  * 
  * Get the tag priority.
  * 
- * Returns: The tag’s priority.
+ * Return value: The tag's priority.
  **/
 gint
 gtk_text_tag_get_priority (GtkTextTag *tag)
@@ -2209,17 +1895,17 @@ gtk_text_tag_get_priority (GtkTextTag *tag)
  * gtk_text_tag_set_priority:
  * @tag: a #GtkTextTag
  * @priority: the new priority
- *
- * Sets the priority of a #GtkTextTag. Valid priorities
+ * 
+ * Sets the priority of a #GtkTextTag. Valid priorities are
  * start at 0 and go to one less than gtk_text_tag_table_get_size().
  * Each tag in a table has a unique priority; setting the priority
  * of one tag shifts the priorities of all the other tags in the
  * table to maintain a unique priority for each tag. Higher priority
- * tags “win” if two tags both set the same text attribute. When adding
+ * tags "win" if two tags both set the same text attribute. When adding
  * a tag to a tag table, it will be assigned the highest priority in
  * the table by default; so normally the precedence of a set of tags
  * is the order in which they were added to the table, or created with
- * gtk_text_buffer_create_tag(), which adds the tag to the buffer’s table
+ * gtk_text_buffer_create_tag(), which adds the tag to the buffer's table
  * automatically.
  **/
 void
@@ -2267,9 +1953,9 @@ gtk_text_tag_set_priority (GtkTextTag *tag,
  * @event: the event
  * @iter: location where the event was received
  * 
- * Emits the “event” signal on the #GtkTextTag.
+ * Emits the "event" signal on the #GtkTextTag.
  * 
- * Returns: result of signal emission (whether the event was handled)
+ * Return value: result of signal emission (whether the event was handled)
  **/
 gboolean
 gtk_text_tag_event (GtkTextTag        *tag,
